==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cellar/dialogs_nl.lua <==

dialogId("pra-m-pravidla", "font_small", "You know the rules already. Now you can practice them. We will give you some hints occasionally.")
dialogStr("Je kent de regels al. Nu kun je wat oefenen. We geven je af en toe wat aanwijzingen.")


dialogId("pra-v-klesnout", "font_big", "I must not swim down now. And I cannot go up, either.")
dialogStr("Ik mag nu niet naar beneden zwemmen. En ik kan ook niet naar boven.")


dialogId("pra-v-nahore", "font_big", "Hey, arrange it up there somehow. But be careful!")
dialogStr("Hee, los dat daar boven eens op. Maar wees wel voorzichtig!")


dialogId("pra-m-nepohnu", "font_small", "I can`t move this. This is steel.")
dialogStr("Dat kan ik niet verplaatsen.  Het is van staal.")


dialogId("pra-m-zpatky", "font_small", "Come back, you can`t go further!")
dialogStr("Kom terug, je kunt niet verder!")


dialogId("pra-v-zapeklita", "font_big", "Hmm... This is tricky. If we push aside the honey, we will be smashed by that can of apricot jam.")
dialogStr("Hmm... Dit is lastig. Als we de honing opzij duwen worden we verpletterd door die pot abrikozenjam.")


dialogId("pra-m-vyrazit", "font_small", "Couldn`t we push it aside with that axe?")
dialogStr("Kunnen we die niet opzij duwen met de bijl?")


dialogId("pra-v-dobrynapad", "font_big", "That`s a good idea.")
dialogStr("Dat is een goed idee.")


dialogId("pra-m-chytit", "font_small", "Now I cannot take the axe. The can is in the way.")
dialogStr("Nu kan ik niet meer bij de bijl. De pot zit in de weg.")


dialogId("pra-v-vzit", "font_big", "You mustn`t push the axe!")
dialogStr("Je mag de bijl niet verplaatsen!")


dialogId("pra-m-prisun", "font_small", "If you can push that can to me, I`ll shove the axe on it and everything will be okay.")
dialogStr("Als je het glas mijn kant op duwt, dan schuif ik de bijl erop en dan komt alles goed.")


dialogId("pra-v-problem", "font_big", "If you solve some specific part you can save the position.")
dialogStr("Als je een stuk hebt opgelost kun je de situatie opslaan.")


dialogId("pra-m-reseni", "font_small", "But only if you are sure of your solution.")
dialogStr("Maar alleen als je zeker weet dat het de goeie oplossing is.")


dialogId("pra-v-ukladani", "font_big", "Remember what we have said about saving positions.")
dialogStr("Vergeet niet wat we net zeiden over de situatie opslaan.")


dialogId("pra-m-uvazovat", "font_small", "I shouldn`t be thinking about this.")
dialogStr("Dit kan ik beter uit mijn hoofd laten.")


dialogId("pra-v-spatne", "font_big", "This looks real bad. You are going to have to restart the level.")
dialogStr("Dit ziet er slecht uit. Je moet het veld herstarten.")


dialogId("pra-m-pustis", "font_small", "If you drop that and I stay here, I will never get out.")
dialogStr("Als je dat laat vallen terwijl ik nog hier ben, dan kom ik er nooit uit.")


dialogId("pra-v-zavazis", "font_big", "You are standing in my way there. Try to hide somewhere else.")
dialogStr("Je drijft in de weg. Probeer je ergens anders te verstoppen.")


dialogId("pra-m-strach", "font_small", "Here? I`m little bit afraid. Will I get out?")
dialogStr("Hier misschien? Ik vind dit een beetje eng. Hoe moet ik hier straks weer uit komen?")


dialogId("pra-v-prekvapit", "font_big", "Just wait and see.")
dialogStr("Wacht maar.")


dialogId("pra-m-kniha", "font_small", "We will give you a hint here, player. You have to put that book over there, to the left.")
dialogStr("We geven je hier wel een aanwijzing, speler. Je moet dat book daar naar links duwen.")


dialogId("pra-v-valec", "font_big", "So that it will catch that steel cylinder when I push it.")
dialogStr("Zodat die stalen cylinder erop terecht komt als ik die een duw geef.")


dialogId("pra-m-jakudelat", "font_small", "But we will not tell you how to do it.")
dialogStr("Maar we vertellen je lekker niet hoe het moet.")


dialogId("pra-v-nezapomen", "font_big", "Just remember that although we cannot push objects along each other`s back, we can push them down or onto some solid structure.")
dialogStr("Vergeet niet dat we misschien geen dingen over elkaars rug kunnen duwen, maar wel er vanaf of op een vast punt.")


dialogId("pra-v-objet", "font_big", "What if I go the upper way?")
dialogStr("Wat als ik de bovenste weg kies?")


dialogId("pra-m-neradit", "font_small", "Shhhh. That`s too many hints.")
dialogStr("Sst. Je zegt te veel voor.")


dialogId("pra-m-stava", "font_small", "Things like that happen sometimes.")
dialogStr("Dat soort dingen gebeuren wel eens.")


dialogId("pra-v-dopredu", "font_big", "Sometimes you have to think faaar ahead.")
dialogStr("Soms moet je heeeeeeel ver vooruit denken.")


dialogId("pra-m-restart", "font_small", "And often you have to restart the level then.")
dialogStr("En dan moet je vaak het veld opnieuw doen.")


dialogId("pra-v-schvalne", "font_big", "We admit that we did this on purpose.")
dialogStr("We moeten toegeven dat we dat expres hebben gedaan.")


dialogId("pra-m-znovu", "font_small", "So that you could try it again - this time without any hints.")
dialogStr("Zodat je het nog een keertje kunt proberen, maar dan zonder aanwijzingen.")

==> fillets-ng-data_0.9.2.orig.tar.gz: fillets-ng-data-0.9.2/script/cellar/dialogs_nl.lua <==

dialogId("pra-m-pravidla", "font_small", "You know the rules already. Now you can practice them. We will give you some hints occasionally.")
dialogStr("Je kent de regels al. Nu kun je wat oefenen. We geven je af en toe wat aanwijzingen.")


dialogId("pra-v-klesnout", "font_big", "I must not swim down now. And I cannot go up, either.")
dialogStr("Ik mag nu niet naar beneden zwemmen. En ik kan ook niet naar boven.")


dialogId("pra-v-nahore", "font_big", "Hey, arrange it up there somehow. But be careful!")
dialogStr("Hee, regel dat daar boven eens. Maar wees wel voorzichtig!")


dialogId("pra-m-nepohnu", "font_small", "I can’t move this. This is steel.")
dialogStr("Dat kan ik niet verplaatsen.  Het is van staal.")


dialogId("pra-m-zpatky", "font_small", "Come back, you can’t go further!")
dialogStr("Kom terug, je kunt niet verder!")


dialogId("pra-v-zapeklita", "font_big", "Hmm... This is tricky. If we push aside the honey, we will be smashed by that can of apricot jam.")
dialogStr("Hmm... Dit is lastig. Als we de honing opzij duwen worden we verpletterd door die pot abrikozenjam.")


dialogId("pra-m-vyrazit", "font_small", "Couldn’t we push it aside with that axe?")
dialogStr("Kunnen we die niet opzij duwen met de bijl?")


dialogId("pra-v-dobrynapad", "font_big", "That’s a good idea.")
dialogStr("Dat is een goed idee.")


dialogId("pra-m-chytit", "font_small", "Now I cannot take the axe. The can is in the way.")
dialogStr("Nu kan ik niet meer bij de bijl. De pot zit in de weg.")


dialogId("pra-v-vzit", "font_big", "You mustn’t push the axe!")
dialogStr("Je moet niet tegen de bijl duwen!")


dialogId("pra-m-prisun", "font_small", "If you can push that can to me, I’ll shove the axe on it and everything will be okay.")
dialogStr("Als je die pot mijn kant op duwt, dan schuif ik de bijl erop en dan komt alles goed.")


dialogId("pra-v-problem", "font_big", "If you solve some specific part you can save the position.")
dialogStr("Als je een stuk hebt opgelost kun je de situatie opslaan.")


dialogId("pra-m-reseni", "font_small", "But only if you are sure of your solution.")
dialogStr("Maar alleen als je zeker weet dat het de goede oplossing is.")


dialogId("pra-v-ukladani", "font_big", "Remember what we have said about saving positions.")
dialogStr("Vergeet niet wat we net zeiden het opslaan van de situatie.")


dialogId("pra-m-uvazovat", "font_small", "I shouldn’t be thinking about this.")
dialogStr("Dit kan ik beter uit mijn hoofd laten.")


dialogId("pra-v-spatne", "font_big", "This looks real bad. You are going to have to restart the level.")
dialogStr("Dit ziet er slecht uit. Je moet het veld herstarten.")


dialogId("pra-m-pustis", "font_small", "If you drop that and I stay here, I will never get out.")
dialogStr("Als je dat laat vallen terwijl ik nog hier ben, dan kom ik er nooit uit.")


dialogId("pra-v-zavazis", "font_big", "You are standing in my way there. Try to hide somewhere else.")
dialogStr("Je zwemt in de weg. Probeer je ergens anders te verstoppen.")


dialogId("pra-m-strach", "font_small", "Here? I’m little bit afraid. Will I get out?")
dialogStr("Hier misschien? Ik vind dit een beetje eng. Hoe moet ik hier straks weer uit komen?")


dialogId("pra-v-prekvapit", "font_big", "Just wait and see.")
dialogStr("Wacht maar.")


dialogId("pra-m-kniha", "font_small", "We will give you a hint here, player. You have to put that book over there, to the left.")
dialogStr("We geven je hier wel een aanwijzing, speler. Je moet dat boek daar naar links duwen.")


dialogId("pra-v-valec", "font_big", "So that it will catch that steel cylinder when I push it.")
dialogStr("Zodat die stalen cylinder erop terecht komt als ik die een duwtje geef.")


dialogId("pra-m-jakudelat", "font_small", "But we will not tell you how to do it.")
dialogStr("Maar we vertellen je lekker niet hoe het moet.")


dialogId("pra-v-nezapomen", "font_big", "Just remember that although we cannot push objects along each other’s back, we can push them down or onto some solid structure.")
dialogStr("Vergeet niet dat we misschien geen dingen over elkaars rug kunnen duwen, maar wel van elkaar af of op een vast punt.")


dialogId("pra-v-objet", "font_big", "What if I go the upper way?")
dialogStr("Wat als ik het bovenste pad kies?")


dialogId("pra-m-neradit", "font_small", "Shhhh. That’s too many hints.")
dialogStr("Sst. Je zegt te veel voor.")


dialogId("pra-m-stava", "font_small", "Things like that happen sometimes.")
dialogStr("Dat soort dingen gebeuren wel eens.")


dialogId("pra-v-dopredu", "font_big", "Sometimes you have to think faaar ahead.")
dialogStr("Soms moet je heeeeeeel ver vooruit denken.")


dialogId("pra-m-restart", "font_small", "And often you have to restart the level then.")
dialogStr("En dan moet je vaak het veld opnieuw doen.")


dialogId("pra-v-schvalne", "font_big", "We admit that we did this on purpose.")
dialogStr("We moeten toegeven dat het expres was.")


dialogId("pra-m-znovu", "font_small", "So that you could try it again - this time without any hints.")
dialogStr("Zodat je het nog een keertje kunt proberen, maar dan zonder aanwijzingen.")
